#!/usr/bin/python3
import traci
# import time
# import csv
from sumolib import checkBinary

import argparse

parser = argparse.ArgumentParser(
    prog='compute-pass-per-vehicle-with-sumo.py',
    usage='%(prog)s [optional arguments] -- SUMOARGS',
    description='Run SUMO and compute passengers per vehicle',
    epilog="Examples\n"
          '  compute-pass-per-vehicle-with-sumo.py -f 500 -l 1000 -v tram1 tram4 -- -c loopAraya.sumocfg\n'
          '    run SUMO with loopAraya.sumocfg, collect data between 500 and 1000 sec for vehicles tram1 and tram4\n'
          '  compute-pass-per-vehicle-with-sumo.py -f 3600 -t 4000 -v 0 1 2 3 -- -c test.sumocfg\n'
          '    run SUMO with test.sumocfg, collect data between 3600 and 4000 sec for vehicles 0,1,2 and 3'
, formatter_class=argparse.RawDescriptionHelpFormatter)
parser.add_argument('-f','--first', type=int, default=0, help='From time')
parser.add_argument('-l','--last', type=int, default=3600, help='From time')
parser.add_argument('-v','--vehicles', nargs='+', help='From time')
parser.add_argument('-g','--gui', action='store_true', help='Use sumo-gui')
parser.add_argument('sumoargs', nargs='+')
args = parser.parse_args()

if args.gui:
  sumoBinary = checkBinary ("sumo-gui")
else:
  sumoBinary = checkBinary ("sumo")

sumoCmd = [sumoBinary, "--quit-on-end", "--start"]
sumoCmd.extend(args.sumoargs)

print('Run ' + ' '.join(sumoCmd))

traci.start(sumoCmd)
step = 0
csvfile = open('passengers.csv', 'w')

def fueling_behavior():
    while step >= 3600:
        traci.simulationStep()
        current_time = traci.simulation.getTime()
        current_fuel_Level = traci.vehicletype.getParameterWithKey("RedBusHDB", "actualBatteryCapacity")
        print (current_time, current_fuel_Level)
        
#         print (current_fuel_Level)

def maintain_headway():
    #For Green Route Buses (ONLY)
    while step > 3600:
        traci.simulationStep()
        
        # Detect Vehicle 6 so that Vehicle 5 can slow down
        leader_id = traci.vehicle.getLeader("5", 30)
        if leader_id[0] == "6" and leader_id[1] <= 50 in leader_id:
            traci.vehicle.slowDown("5", 0.1, 100)

#         if leader_id >= ("6", 15):
#             traci.vehicle.openGap("5", 360, 1850, 300, -0.5, -0.5, "6")
#             traci.vehicle.getSt

        
while traci.simulation.getMinExpectedNumber() > 0:
  traci.simulationStep()
  
  # Execution for Beginning of Simulation
  # do nothing special
  # Execution for collecting Ridership within Bus Vehicles
  if args.first <= step:
        # This set of code gets the number of riders currently within the bus
        simulation_runtime = traci.simulation.getTime()
        list_of_ridership = [str(simulation_runtime)]
        for id in args.vehicles:
          # take care, if vehicle does not exist
          try:
            ridership = traci.vehicle.getPersonNumber(id)
          except:
            ridership = 0
          list_of_ridership.append(str(ridership))
        # create a comma-separated list
        print(','.join(list_of_ridership), file=csvfile, flush=True)
  if step > args.last:
    break

  step += 1
  fueling_behavior()
  maintain_headway()
  
csvfile.close()
traci.close()


